@@ -1,8 +1,8 @@
-from .classifier import (MLP, RNN, SVM, AdaBoost, Keras, RandomForest,
+from .classifier import (MLP, RNN, SVM, TFMLP, AdaBoost, Keras, RandomForest,
                          Transformer, XGBoost)
 from .embedding import CountVectorizer, Doc2Vec, OneHot, Sequence, TfIdf
-from .linguistics import (Contract, FindAll, Lemmatizer, Phrase, Snowball, Sub,
-                          Tokenize)
+from .linguistics import (Contract, FindAll, Lemmatizer, NGram, Phrase,
+                          Snowball, Sub, Tokenize)
 from .multi import Merge
 from .preprocessing import Normalize
 from .reduction import NMF, PCA, SVD, UMAP
@@ -12,8 +12,8 @@ from .special import DomainName, Lambda, SplitHashtag
 __all__ = [
     "Tokenize", "Snowball", "Phrase", "Sub", "Contract", "FindAll",
     "TfIdf", "CountVectorizer", "Sequence", "OneHot", "Doc2Vec",
-    "SVD", "PCA", "NMF", "UMAP", "Lemmatizer",
+    "SVD", "PCA", "NMF", "UMAP", "Lemmatizer", "NGram",
     "RandomForest", "AdaBoost", "SVM", "MLP", "Keras", "Transformer",
-    "XGBoost", "Merge", "Normalize", "SplitHashtag",
+    "XGBoost", "Merge", "Normalize", "SplitHashtag", "TFMLP",
     "MLPRegressor", "KerasRegressor", "Lambda", "RNN", "DomainName"
 ]
